@@ -27,6 +27,10 @@ def extract_series_title_feature(soup):
     return ret
 
 
+def valueIfDefinedOrNONE(value):
+    return value if value else "NONE"
+
+
 class MovieParse:
     def __init__(self, url, timeSupplied=None):
         self.url = url
@@ -137,25 +141,11 @@ class MovieParse:
             print(self.length)
         print(self.title)
         print('##' + self.title + ' Watched')
-        if self.director:
-            print(self.director)
-        else:
-            print("NONE")
 
-        if self.country:
-            print(self.country)
-        else:
-            print("NONE")
-
-        if self.stars:
-            print(self.stars)
-        else:
-            print("NONE")
-        print()
-        if self.descr:
-            print(self.descr)
-        else:
-            print("NONE")
+        print(valueIfDefinedOrNONE(self.director))
+        print(valueIfDefinedOrNONE(self.country))
+        print(valueIfDefinedOrNONE(self.stars))
+        print(valueIfDefinedOrNONE(self.descr))
 
     def addViaApi(self, supplied_length=None, collection=None):
         put_uri = "http://localhost:8080/rest/movie"
